@@ -17,12 +17,12 @@
 #
 import os
 from configparser import ConfigParser
-from tempfile import NamedTemporaryFile
 from typing import (
     List, Dict
 )
 
 # project
+from kiwi.utils.temporary import Temporary
 from kiwi.repository.base import RepositoryBase
 from kiwi.path import Path
 from kiwi.command import Command
@@ -52,9 +52,9 @@ class RepositoryPacman(RepositoryBase):
         self.check_signatures = False
         self.repo_names: List = []
 
-        self.runtime_pacman_config_file = NamedTemporaryFile(
+        self.runtime_pacman_config_file = Temporary(
             dir=self.root_dir
-        )
+        ).new_file()
 
         if 'check_signatures' in self.custom_args:
             self.custom_args.remove('check_signatures')
@@ -112,7 +112,8 @@ class RepositoryPacman(RepositoryBase):
         prio: int = None, dist: str = None, components: str = None,
         user: str = None, secret: str = None, credentials_file: str = None,
         repo_gpgcheck: bool = False, pkg_gpgcheck: bool = False,
-        sourcetype: str = None, use_for_bootstrap: bool = False
+        sourcetype: str = None, use_for_bootstrap: bool = False,
+        customization_script: str = None
     ) -> None:
         """
         Add pacman repository
@@ -130,6 +131,8 @@ class RepositoryPacman(RepositoryBase):
         :param bool pkg_gpgcheck: enable package signature validation
         :param str sourcetype: unused
         :param bool use_for_bootstrap: unused
+        :param str customization_script:
+            custom script called after the repo file was created
         """
         repo_file = '{0}/{1}.repo'.format(
             self.shared_pacman_dir['repos-dir'], name
@@ -151,6 +154,8 @@ class RepositoryPacman(RepositoryBase):
 
         with open(repo_file, 'w') as config:
             repo_config.write(config)
+        if customization_script:
+            self.run_repo_customize(customization_script, repo_file)
 
     def import_trusted_keys(self, signing_keys: List) -> None:
         """
